{ pkgs-unstable, pkgs, ... }:
let
  # Create a script to fix electron apps
  fix-electron-apps = pkgs.writeScriptBin "fix-electron-apps" (
    builtins.readFile ./fix-electron-apps.sh
  );
in
{
  home.packages = with pkgs; [
    # Custom scripts
    fix-electron-apps

    # GUI Application
    ## Utilities
    tea # A Gitea official CLI client
    mission-center # Task Manager like Windows 11
    pinta # Paint.NET alternative
    smile # Emoji picker
    deja-dup # Backup tool
    sqlitebrowser # SQLite database manager
    gparted # Used to nuke Windows off of my system
    rpi-imager # Raspberry Pi OS image writer
    pavucontrol # PulseAudio volume control
    qrencode # qr code generator
    grimblast # Screenshot tool
    gpredict # Satellite tracking

    ## Multimedia
    plex-media-player
    vlc

    ## Astronomy
    stellarium

    ## Games
    ### Open-source games
    openra
    xonotic
    mindustry
    shattered-pixel-dungeon

    ### Games launchers
    lutris
    heroic
    dosbox

    ### Game utilities
    protonup-qt
    protontricks

    ### Virtualization
    virt-manager
    virt-viewer

    ### Remote connection for Android to PC (Over ADB)
    scrcpy
  ];

  # Fix for all Electron apps' chrome-sandbox
  home.activation.fixElectronChromeSandbox = ''
    echo ""
    echo "=============================================="
    echo "IMPORTANT: Electron Applications Notice"
    echo "=============================================="
    echo "Some Electron applications (like Vesktop) may need"
    echo "special permissions to run correctly."
    echo ""
    echo "If you encounter issues with Electron apps, run:"
    echo "  fix-electron-apps"
    echo ""
    echo "This command will properly set permissions on all"
    echo "Electron sandbox files in your system."
    echo "=============================================="
    echo ""
  '';
}
